@@ -100,6 +100,7 @@ sub __is_NonNative {
 	
 	return undef if $size < 12;
 	open(TNN, $file) or return undef;
+	binmode(TNN);
 	seek(TNN,0,0);
 	read(TNN,$magic,4);
 	seek(TNN,8,0);
@@ -181,6 +182,7 @@ sub __is_pcm {
 	my $size = (-s $file);
 	return undef if $size < 32;
 	open(PCM, "$file") or return undef;
+	binmode(PCM);
 	#Get the group id and riff type
 	my ($gid, $rty, $buff,$srate,$bps) = undef;
 	
@@ -407,6 +409,7 @@ sub kick_convert {
 	$quality = 0 if $quality < 0;
 	$quality = 9 if $quality > 9;
 	open(KICKOMATIC, "-|") or exec($prog, $file, "GET_$format", int($quality)) or die "FileMagic::kick_convert: Could not exec $prog\n";
+	binmode(KICKOMATIC);
 	my $newP = <KICKOMATIC>;
 	chomp($newP);
 	close(KICKOMATIC);
@@ -472,6 +475,7 @@ sub converter_readmeta {
 	$prog = "$con->{bindir}/$prog";
 	my %metastuff = ();
 	open(CFLAC, "-|") or exec($prog, $file, "GET_META") or die "converter_readmeta: Could not exec $prog\n";
+	binmode(CFLAC);
 	while(<CFLAC>) {
 		chomp($_);
 		if($_ =~ /^([^:]+):(.*)$/) {
