@@ -42,11 +42,12 @@ $int_count = 3; #The user has to send INT (Ctrl+C) x times until we stop
 
 $opts{mount} = $ENV{IPOD_MOUNTPOINT};
 #Don't add xml and itunes opts.. we *NEED* the mount opt to be set..
-GetOptions(\%opts, "version", "help|h", "mount|m=s", "decode=s", "restore|r", "duplicate|d", "disable-v2", "disable-v1",
-                   "set-title=s", "set-artist=s", "set-album=s", "set-genre=s", "set-rating=i", "set-playcount=i",
-                   "set-bookmarkable", "set-shuffleskip", "artwork=s",
+GetOptions(\%opts, "version", "help|h", "mount|m=s", "decode|x=s", "restore|r", "duplicate|d", "disable-v2", "disable-v1",
+                   "set-title|t=s", "set-artist|a=s", "set-album|l=s", "set-genre|g=s", "set-rating=i", "set-playcount=i",
+                   "set-bookmarkable|b", "set-shuffleskip", "artwork=s",
                    "set-songnum", "playlist|p=s@", "reencode|e=i",
                    "min-vol-adj=i", "max-vol-adj=i", "playlist-is-podcast", "set-compilation");
+
 GNUpod::FooBar::GetConfig(\%opts, {'decode'=>'s', mount=>'s', duplicate=>'b', model=>'s',
                                    'disable-v1'=>'b', 'disable-v2'=>'b', 'set-songnum'=>'b',
                                    'min-vol-adj'=>'i', 'max-vol-adj'=>'i', 'automktunes'=>'b' },
@@ -65,7 +66,7 @@ if($opts{restore}) {
 	print "If you use --restore, you'll *lose* your playlists and cover artwork!\n";
 	print " Hit ENTER to continue or CTRL+C to abort\n\n";
 	<STDIN>;
-	@XFILES = bsd_glob("$opts{mount}/iPod_Control/Music/*/*", GLOB_NOSORT)
+	@XFILES = bsd_glob("$opts{mount}/i*/Music/F*/*", GLOB_NOSORT)
 }
 elsif($ARGV[0] eq "-" && @ARGV == 1) {
 	print STDERR "Reading from STDIN, hit CTRL+D (EOF) when finished\n";
@@ -285,7 +286,7 @@ sub startup {
 		$fh->{volume} = $vol;
 		
 		#Get a path
-		($fh->{path}, my $target) = GNUpod::XMLhelper::getpath($opts{mount}, $file,  {format=>$wtf_frmt, extension=>$wtf_ext, keepfile=>$opts{restore}});
+		($fh->{path}, my $target) = GNUpod::XMLhelper::getpath($connection, $file,  {format=>$wtf_frmt, extension=>$wtf_ext, keepfile=>$opts{restore}});
 		
 		if(!defined($target)) {
 			warn "*** FATAL *** Skipping '$file' , no target found!\n";
@@ -376,11 +377,11 @@ sub newpl {
 #### PODCAST START ####
 
 #############################################################
-# Calls wget to get files
+# Calls curl to get files
 sub PODCAST_fetch {
 	my($url,$prefix) = @_;
 	my $tmpout = GNUpod::FooBar::get_u_path($prefix,"");
-	my $return = system("wget", "-q", "-O", $tmpout, $url);
+	my $return = system("curl", "-s", "-L", "-o", $tmpout, $url);
 	return{file=>$tmpout, status=>$return};
 }
 
@@ -431,7 +432,7 @@ sub resolve_podcasts {
 	my $env_is_okay = 1 if $opts{playlist} && $opts{'playlist-is-podcast'};
 	
 	foreach my $cf (@xfiles) {
-		if($cf =~ /^http:\/\//i) {
+		if (($cf =~ /^http:\/\//i) || ($cf =~ /^file:\/\//i)) {
 			$i++;
 			print "* [HTTP] Fetching Podcast #$i: $cf\n";
 			
@@ -442,7 +443,7 @@ sub resolve_podcasts {
 			
 			my $pcrss = PODCAST_fetch($cf, "/tmp/gnupodcast$i");
 			if($pcrss->{status} or (!(-f $pcrss->{file}))) {
-				warn "! [HTTP] Failed to download the file '$cf', wget exitcode: $pcrss->{status}\n";
+				warn "! [HTTP] Failed to download the file '$cf', curl exitcode: $pcrss->{status}\n";
 				next;
 			}
 			#Add the stuff to %podcast_infos and unlink the file after this.
@@ -548,20 +549,20 @@ Usage: gnupod_addsong.pl [-h] [-m directory] File1 File2 ...
        --playlist-is-podcast        Set podcast flag for playlist(s) created using '--playlist'
        --disable-v1                 Do not read ID3v1 Tags (MP3 Only)
        --disable-v2                 Do not read ID3v2 Tags (MP3 Only)
-       --decode=pcm|mp3|aac|aacbm   Convert FLAC Files to WAVE/MP3 or AAC 'on-the-fly'
-       --decode=video               Convert .avi Files into iPod video 'on-the-fly' (needs ffmpeg with AAC support!)
+   -x  --decode=pcm|mp3|aac|aacbm   Convert FLAC Files to WAVE/MP3 or AAC 'on-the-fly'. Use '-e' to specify a quality/bitrate
+   -x  --decode=video               Convert .avi Files into iPod video 'on-the-fly' (needs ffmpeg with AAC support)
    -e  --reencode=int               Reencode MP3/AAC files with new quality 'on-the-fly'
                                     (0 = Good .. 9 = Bad)
                                     You may be able to save some space if you do not need
                                     crystal-clear sound ;-)
-       --set-title=string           Set Title  (Override ID3 Tag)
-       --set-artist=string          Set Artist (Override ID3 Tag)
-       --set-album=string           Set Album  (Override ID3 Tag)
-       --set-genre=string           Set Genre  (Override ID3 Tag)
+   -t  --set-title=string           Set Title  (Override ID3 Tag)
+   -a  --set-artist=string          Set Artist (Override ID3 Tag)
+   -l  --set-album=string           Set Album  (Override ID3 Tag)
+   -g  --set-genre=string           Set Genre  (Override ID3 Tag)
        --set-rating=int             Set Rating
        --set-playcount=int          Set Playcount
        --set-songnum                Override 'Songnum/Tracknum' field
-       --set-bookmarkable           Set this song as bookmarkable (= Remember position)
+   -b  --set-bookmarkable           Set this song as bookmarkable (= Remember position)
        --set-shuffleskip            Exclude this file in shuffle-mode
        --set-compilation            Mark songs as being part of a compilation
        --min-vol-adj=int            Minimum volume adjustment allowed by ID3v2.4 RVA2 tag
